# -*- coding: utf-8 -*-
# orbit position calculation
# date: 2022/01/26 JST
# author: D.Nakayama

import ephem
import sys
import datetime
import numpy as np
import csv

print(len(sys.argv))
print(sys.argv)

if(len(sys.argv )!=9):
    print("usage: python3 TLE2POS.py <TLE Path> <Latitude> <Longitude> <Height> <DATE(UCT)> <TIME> <Dulation[s]> <deltaT>")
    print("e.g.   python3 AOSM.py tle.txt 33.8925 130.8401 50.0 2021/12/15 06:19:40 100 0.016384")
    exit()

tleFilePath = sys.argv[1]

GS           = ephem.Observer()
GS.lat       = sys.argv[2]
GS.lon       = sys.argv[3]
GS.elevation = float( sys.argv[4] )

initial_date = datetime.datetime.strptime( sys.argv[5] + " " + sys.argv[6], '%Y/%m/%d %H:%M:%S' )
dulation = float(sys.argv[7])
deltaT = float(sys.argv[8])

f=open(tleFilePath, "r")
tleFile = f.read()
tleList = tleFile.split("\n")
tle = tleList[:3]

date = initial_date

with open('./POS.csv', 'w') as f:
    writer = csv.writer(f)
    writer.writerow(["date time", "Elapsed[sec]", "Azimuth[deg]", "Elevation[deg]", "Range[m]", "Range velocity[m/s]", "Eclipsed"])

    while True:
    #    print(date)
        
        sat = ephem.readtle(tle[0], tle[1], tle[2])
        GS.date = date
        sat.compute(GS)
        info = [ "{0}".format(date), (date-initial_date).seconds + (date-initial_date).microseconds / 1000000 , np.degrees(sat.az), np.degrees(sat.alt), sat.range, sat.range_velocity, sat.eclipsed]
        print(info)
        writer.writerow(info)

        date = date + datetime.timedelta( seconds = deltaT )
        if( date > initial_date + datetime.timedelta( seconds = dulation ) ):
            break
    

